@@ -1,10 +1,10 @@
-__version__ = "0.1.6"
+__version__ = "0.2.2"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
 __git_branch__ = '(Not currently on any branch)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = '6ce959dd2f4a518359a903f8fb938d701cc20c82'
-__git_head_subject__ = 'Finished release v0.1.6.'
+__git_head_hash__ = 'f6d45baf128fd768cdb57ed476790acae0d852ea'
+__git_head_subject__ = 'empty commit after version v0.1.6'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
